@@ -12,8 +12,12 @@
 ( cd opt/kde/lib ; ln -sf libkdeeduui.so.1.2.0 libkdeeduui.so.1 )
 ( cd opt/kde/lib ; rm -rf libkdeeduplot.so.1 )
 ( cd opt/kde/lib ; ln -sf libkdeeduplot.so.1.2.0 libkdeeduplot.so.1 )
+( cd opt/kde/lib ; rm -rf libextdate.so.1 )
+( cd opt/kde/lib ; ln -sf libextdate.so.1.2.0 libextdate.so.1 )
 ( cd opt/kde/lib ; rm -rf libkdeeduplot.so )
 ( cd opt/kde/lib ; ln -sf libkdeeduplot.so.1.2.0 libkdeeduplot.so )
+( cd opt/kde/lib ; rm -rf libextdate.so )
+( cd opt/kde/lib ; ln -sf libextdate.so.1.2.0 libextdate.so )
 ( cd opt/kde/lib ; rm -rf libkdeeduui.so )
 ( cd opt/kde/lib ; ln -sf libkdeeduui.so.1.2.0 libkdeeduui.so )
 ( cd opt/kde/lib ; rm -rf libkdeeducore.so )
@@ -30,16 +34,18 @@
 ( cd opt/kde/share/doc/HTML/en/kiten ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kvoctrain ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kturtle ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kverbos ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/flashkard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/flashkard ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kbruch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kbruch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/keduca ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/klatin ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kmplot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kstars ; rm -rf common )
@@ -50,3 +56,5 @@
 ( cd opt/kde/share/doc/HTML/en/klettres ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kmathtool ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kmathtool ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/en/common common )
